@@ -10,9 +10,10 @@ These are extra functionality for Igor
 import requests, shutil
 from typing import Optional, Dict
 from .pyrosetta_import import pyrosetta  # the real mcCoy or a mock.
+from ._igor_base import _IgorBase
 
 
-class _IgorUtils:
+class _IgorUtils(_IgorBase):
 
     def dock(self) -> pyrosetta.Pose:
         """
